# Docker Compose

Example Docker Compose configuration to run *updates2mqtt* as a container. This also
requires a [.env](env.md), or alternatively adding the environment variables directly into the
compose file.

``` yaml
--8<-- "examples/docker-compose.yaml"
```